@@ -7,7 +7,7 @@ use Mojo::Base 'Mojolicious::Plugin::Prove::Base';
 use File::Basename;
 use File::Spec;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub register {
     my ($self, $app, $conf) = @_;
@@ -24,11 +24,11 @@ sub register {
     # Add template path
     $self->add_template_path($app->renderer, __PACKAGE__);
     
-    # Add ṕublic path
+    # Add public path
     my $static_path = File::Spec->catdir( dirname(__FILE__), 'Prove', 'public' );
     push @{ $app->static->paths }, $static_path;
     
-    $app->plugin( 'PPI' );
+    $app->plugin( 'PPI' => { no_check_file => 1 } );
     
     # Routes
     my $r      = $conf->{route}  // $app->routes;
@@ -56,17 +56,19 @@ sub register {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Mojolicious::Plugin::Prove - run test scripts via browser
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -97,15 +99,14 @@ version 0.01
 
 =head1 AUTHOR
 
-Renee Baecker <module@renee-baecker.de>
+Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Renee Baecker.
+This software is Copyright (c) 2015 by Renee Baecker.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
